==> scala-k8s-objects_sjs1_2.13-0.4.0-sources.jar: io/k8s/api/flowcontrol/v1beta2/PriorityLevelConfiguration.scala <==
package io.k8s.api.flowcontrol.v1beta2

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** PriorityLevelConfiguration represents the configuration of a priority level. */
final case class PriorityLevelConfiguration(
  status : Option[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationStatus] = None,
  spec : Option[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationSpec] = None,
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("flowcontrol.apiserver.k8s.io", "PriorityLevelConfiguration", "v1beta2")


  /** Returns a new data with status set to new value */
  def withStatus(value: io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationStatus) : PriorityLevelConfiguration = copy(status = Some(value))
  /** if status has a value, transforms to the result of function*/
  def mapStatus(f: io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationStatus => io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationStatus) : PriorityLevelConfiguration = copy(status = status.map(f))

  /** Returns a new data with spec set to new value */
  def withSpec(value: io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationSpec) : PriorityLevelConfiguration = copy(spec = Some(value))
  /** if spec has a value, transforms to the result of function*/
  def mapSpec(f: io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationSpec => io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationSpec) : PriorityLevelConfiguration = copy(spec = spec.map(f))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : PriorityLevelConfiguration = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : PriorityLevelConfiguration = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = PriorityLevelConfiguration.encoder.apply(this)
}

object PriorityLevelConfiguration {

    implicit val encoder : Encoder[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfiguration] = new Encoder[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfiguration] {
        def apply[T : Builder](o: io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfiguration) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("status", o.status)
            .write("spec", o.spec)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit val decoder: Decoder[PriorityLevelConfiguration] = new Decoder[PriorityLevelConfiguration] {
      def apply[T : Reader](t: T): Either[String, PriorityLevelConfiguration] = for {
          obj <- ObjectReader(t)
          status <- obj.readOpt[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationStatus]("status")
          spec <- obj.readOpt[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationSpec]("spec")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta]("metadata")
      } yield PriorityLevelConfiguration (
          status = status,
          spec = spec,
          metadata = metadata
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.3.0-sources.jar: io/k8s/api/flowcontrol/v1beta2/PriorityLevelConfiguration.scala <==
package io.k8s.api.flowcontrol.v1beta2

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** PriorityLevelConfiguration represents the configuration of a priority level. */
final case class PriorityLevelConfiguration(
  status : Option[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationStatus] = None,
  spec : Option[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationSpec] = None,
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("flowcontrol.apiserver.k8s.io", "PriorityLevelConfiguration", "v1beta2")


  /** Returns a new data with status set to new value */
  def withStatus(value: io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationStatus) : PriorityLevelConfiguration = copy(status = Some(value))
  /** if status has a value, transforms to the result of function*/
  def mapStatus(f: io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationStatus => io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationStatus) : PriorityLevelConfiguration = copy(status = status.map(f))

  /** Returns a new data with spec set to new value */
  def withSpec(value: io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationSpec) : PriorityLevelConfiguration = copy(spec = Some(value))
  /** if spec has a value, transforms to the result of function*/
  def mapSpec(f: io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationSpec => io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationSpec) : PriorityLevelConfiguration = copy(spec = spec.map(f))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : PriorityLevelConfiguration = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta) : PriorityLevelConfiguration = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = PriorityLevelConfiguration.encoder[T].apply(this)
}

object PriorityLevelConfiguration {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfiguration, T] = new Encoder[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfiguration, T] {
        def apply(o: io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfiguration) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("status", o.status)
            .write("spec", o.spec)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, PriorityLevelConfiguration] = new Decoder[T, PriorityLevelConfiguration] {
      def apply(t: T): Either[String, PriorityLevelConfiguration] = for {
          obj <- ObjectReader(t)
          status <- obj.readOpt[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationStatus]("status")
          spec <- obj.readOpt[io.k8s.api.flowcontrol.v1beta2.PriorityLevelConfigurationSpec]("spec")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta]("metadata")
      } yield PriorityLevelConfiguration (
          status = status,
          spec = spec,
          metadata = metadata
        )
    }
}
